////////////////////////////
// Tinghg et al.1 take issue with two of the 
// ten experiments in our 2012 Nature paper (studies 6 and 7). 
// Here we reanalyse the data from these experiments as 
// suggested by Tinghg et al.1, and demonstrate that our 
// reported positive effect of time pressure on cooperation 
// is not an artefact. 
//
// Specifically, Tinghog make two criticisms of our data analysis.
// 1) In our main analyses, we exclude subjects who did not
//    obey the time constraint (i.e. answered too slowly in
//    the time pressure condition or answered too quickly
//    in the time delay condition)
// 2) In our SI analysis, we include these subjects, but also 
//    in a control in our regressions for 'Failure to obey time
//    constraint'
//
// They suggest instead including all subjects, and not controlling 
// for failure to obey the time constraint. 
//
// Here we do the analysis as they suggest, and show that our 
// finding is robust to this alternate method


///////////////////////////
// LOADING DATA
clear
insheet using "data_for_reply_to_tinghog.txt"
// Make a dummy for Time Pressure
gen time_pressure=(condition=="Time pressure")
// Make contribution variables needed for Tobit regression with robust SEs in STATA
gen cont0=contribution
replace cont0=. if contribution==0
gen cont1=contribution
replace cont1=. if contribution==1
// Make a numeric version of the education variable for use in the ANOVA
encode education, generate(education_numerical)



////////////////////////////
// ANALYSIS

// Contribution in time pressure vs time delay, combining both time presure studies
ranksum contribution, by(time_pressure)

// Linear regression with robust SEs
//      Significant positive effect of time pressure
xi: reg contribution time_pressure, r
xi: reg contribution time_pressure i.study, r
xi: reg contribution time_pressure i.study failedcomprehension age female usresident i.education, r
//      No interaction between study and time pressure 
//      - thus it is appropriate to pool the two studies
xi: reg contribution time_pressure i.study*time_pressure , r
xi: reg contribution time_pressure i.study*time_pressure failedcomprehension age female usresident i.education, r

// Tobit regression with robust SEs
//      Significant positive effect of time pressure
xi: intreg cont0 cont1 time_pressure, r
xi: intreg cont0 cont1 time_pressure i.study, r
xi: intreg cont0 cont1 time_pressure i.study failedcomprehension age female usresident i.education, r
//      No interaction between study and time pressure 
//      - thus it is appropriate to pool the two studies
xi: intreg cont0 cont1 time_pressure i.study*time_pressure , r
xi: intreg cont0 cont1 time_pressure i.study*time_pressure failedcomprehension age female usresident i.education, r

// And for those who prefer ANOVA
anova contribution time_pressure##study 
anova contribution time_pressure##study failedcomprehension c.age female usresident education_numerical
